@@ -7,7 +7,7 @@ from airflow_commons.resources.bigquery import (
     ARCHIVE_SOURCE_STATEMENT_FILE,
     ARCHIVE_DELETE_WHERE_STATEMENT_FILE,
 )
-from airflow_commons.utils.bigquery.bigquery_utils import (
+from airflow_commons.internal.bigquery.bigquery_utils import (
     DEFAULT_TIMEOUT,
     DEFAULT_LOCATION,
     DEFAULT_RETURN_TYPE,
@@ -21,14 +21,14 @@ from airflow_commons.utils.bigquery.bigquery_utils import (
     get_primitive_column_list,
     get_job_config,
 )
-from airflow_commons.utils.bigquery.sql_utils import (
+from airflow_commons.internal.bigquery.sql_utils import (
     get_deduplication_source_statement,
     get_merge_sql,
     get_delete_sql,
     get_deduplication_additional_merge_conditions,
 )
-from airflow_commons.utils.file_utils import read_sql
-from airflow_commons.utils.time_utils import get_buffered_timestamp
+from airflow_commons.internal.file_utils import read_sql
+from airflow_commons.internal.time_utils import get_buffered_timestamp
 
 ARCHIVE_MODES = ["INSERT", "UPSERT"]
 DEFAULT_PRIMARY_KEYS = ["id"]
